@@ -47,7 +47,7 @@ OPT_HDRS = [b'message-id']
 KEYCACHE = dict()
 
 # My version
-__VERSION__ = '0.4.6'
+__VERSION__ = '0.4.8'
 MAX_SUPPORTED_FORMAT_VERSION = 1
 
 
@@ -1089,17 +1089,15 @@ def cmd_genkey(cmdargs, config: dict) -> None:
         logger.critical('Wrote: %s', pkey)
 
     # Also copy it into our local keyring
+    spkey = os.path.join(pdir, make_pkey_path('ed25519', config.get('identity'), identifier))
+    Path(os.path.dirname(spkey)).mkdir(parents=True, exist_ok=True)
+    with open(spkey, 'wb') as fh:
+        fh.write(base64.b64encode(newkey.verify_key.encode()))
+        logger.critical('Wrote: %s', spkey)
     dpkey = os.path.join(pdir, make_pkey_path('ed25519', config.get('identity'), 'default'))
-    Path(os.path.dirname(dpkey)).mkdir(parents=True, exist_ok=True)
     if not os.path.exists(dpkey):
-        with open(dpkey, 'wb') as fh:
-            fh.write(base64.b64encode(newkey.verify_key.encode()))
-            logger.critical('Wrote: %s', dpkey)
-    else:
-        spkey = os.path.join(pdir, make_pkey_path('ed25519', config.get('identity'), identifier))
-        with open(spkey, 'wb') as fh:
-            fh.write(base64.b64encode(newkey.verify_key.encode()))
-            logger.critical('Wrote: %s', spkey)
+        # symlink our new key to be the default
+        os.symlink(identifier, dpkey)
 
     logger.critical('Add the following to your .git/config (or global ~/.gitconfig):')
     logger.critical('---')
@@ -1115,6 +1113,23 @@ def cmd_genkey(cmdargs, config: dict) -> None:
     logger.critical(pkey)
 
 
+def cmd_install_hook(cmdargs, config: dict):  # noqa
+    gitrepo = get_git_toplevel()
+    if not gitrepo:
+        logger.critical('Not in a git tree, cannot install hook')
+        sys.exit(1)
+    hookfile = os.path.join(gitrepo, '.git', 'hooks', 'sendemail-validate')
+    if os.path.exists(hookfile):
+        logger.critical('Hook already exists: %s', hookfile)
+        sys.exit(1)
+    with open(hookfile, 'w') as fh:
+        fh.write('#!/bin/sh\n')
+        fh.write('# installed by patatt install-hook\n')
+        fh.write('patatt sign --hook "${1}"\n')
+        os.chmod(hookfile, 0o755)
+    logger.critical('Hook installed as %s', hookfile)
+
+
 def command() -> None:
     import argparse
     # noinspection PyTypeChecker
@@ -1150,6 +1165,9 @@ def command() -> None:
                         help='Overwrite any existing keys, if found')
     sp_gen.set_defaults(func=cmd_genkey)
 
+    sp_install = subparsers.add_parser('install-hook', help='Install sendmail-validate hook into the current repo')
+    sp_install.set_defaults(func=cmd_install_hook)
+
     _args = parser.parse_args()
 
     logger.setLevel(logging.DEBUG)
